GitHub · Build software better, together.
Description: GitHub is the best place to build software together. Over 4 million people use GitHub to share code.

Skip to content

Use at least one lowercase letter, one numeral, and seven characters.

By clicking "Sign up for GitHub", you agree to our terms of service and privacy policy. We will send you account related emails occasionally.

# Build software better, together.

Powerful collaboration, code review, and code management for open source and private projects. Need private repositories? Upgraded plans start at $7/mo.

## Introducing a faster,
more flexible GitHub Enterprise.

Now available on AWS.

Tell me more

# Why you’ll love GitHub.

Powerful features to make software development more collaborative.

### Great collaboration starts with communication.

Review changes, comment on lines of code, report issues, and plan the future of your project with discussion tools.

### Friction-less development across teams.

Work with project collaborators or teams of people in organization accounts to communicate with ease.

### World’s largest open source community.

Share your projects with the world, get feedback, and contribute to millions of repositories hosted on GitHub.

### Do more with powerful integrations.

Discover applications and tools that integrate with GitHub to help you and your team build software better, together.

# The easiest way to use GitHub on Mac

# The easiest way to use GitHub on Windows

Download GitHub for Mac

OS X 10.8 or later. Learn more

Download GitHub for Windows

For Windows Vista, 7, 8, & 8.1 · Learn more

### You can also use GitHub on Windows.

### You can also use GitHub on Mac.

Something went wrong with that request. Please try again.